[compiler-rt] r230506 - Reland r230019 - [ASan] Make the argument of '__sanitizer_annotate_contiguous_container' is not aligned error message easier to understand

Timur Iskhodzhanov timurrrr at google.com
Wed Feb 25 09:03:34 PST 2015


Author: timurrrr
Date: Wed Feb 25 11:03:34 2015
New Revision: 230506

URL: http://llvm.org/viewvc/llvm-project?rev=230506&view=rev
Log:
Reland r230019 - [ASan] Make the argument of '__sanitizer_annotate_contiguous_container' is not aligned error message easier to understand

This incorporates the fix for ARM architecture suggested by Renato Golin.


Modified:
    compiler-rt/trunk/lib/asan/asan_report.cc
    compiler-rt/trunk/test/asan/TestCases/contiguous_container_crash.cc

Modified: compiler-rt/trunk/lib/asan/asan_report.cc
URL: http://llvm.org/viewvc/llvm-project/compiler-rt/trunk/lib/asan/asan_report.cc?rev=230506&r1=230505&r2=230506&view=diff
==============================================================================
--- compiler-rt/trunk/lib/asan/asan_report.cc (original)
+++ compiler-rt/trunk/lib/asan/asan_report.cc Wed Feb 25 11:03:34 2015
@@ -834,6 +834,9 @@ void ReportBadParamsToAnnotateContiguous
          "      old_mid : %p\n"
          "      new_mid : %p\n",
          beg, end, old_mid, new_mid);
+  uptr granularity = SHADOW_GRANULARITY;
+  if (!IsAligned(beg, granularity))
+    Report("ERROR: beg is not aligned by %d\n", granularity);
   stack->Print();
   ReportErrorSummary("bad-__sanitizer_annotate_contiguous_container", stack);
 }

Modified: compiler-rt/trunk/test/asan/TestCases/contiguous_container_crash.cc
URL: http://llvm.org/viewvc/llvm-project/compiler-rt/trunk/test/asan/TestCases/contiguous_container_crash.cc?rev=230506&r1=230505&r2=230506&view=diff
==============================================================================
--- compiler-rt/trunk/test/asan/TestCases/contiguous_container_crash.cc (original)
+++ compiler-rt/trunk/test/asan/TestCases/contiguous_container_crash.cc Wed Feb 25 11:03:34 2015
@@ -1,6 +1,7 @@
 // RUN: %clangxx_asan -O %s -o %t
 // RUN: not %run %t crash 2>&1 | FileCheck --check-prefix=CHECK-CRASH %s
 // RUN: not %run %t bad-bounds 2>&1 | FileCheck --check-prefix=CHECK-BAD %s
 // RUN: env ASAN_OPTIONS=detect_container_overflow=0 %run %t crash
 //
 // Test crash due to __sanitizer_annotate_contiguous_container.
@@ -21,21 +22,31 @@ int TestCrash() {
   t[60] = 0;
   __sanitizer_annotate_contiguous_container(&t[0], &t[0] + 100, &t[0] + 100,
                                             &t[0] + 50);
+// CHECK-CRASH: AddressSanitizer: container-overflow
   return (int)t[60 * one];  // Touches the poisoned memory.
 }
 
 void BadBounds() {
   long t[100];
+// CHECK-BAD-BOUNDS: ERROR: AddressSanitizer: bad parameters to __sanitizer_annotate_contiguous_container
   __sanitizer_annotate_contiguous_container(&t[0], &t[0] + 100, &t[0] + 101,
                                             &t[0] + 50);
 }
 
+void BadAlignment() {
+  int t[100];
+// CHECK-BAD-ALIGNMENT: ERROR: AddressSanitizer: bad parameters to __sanitizer_annotate_contiguous_container
+// CHECK-BAD-ALIGNMENT: ERROR: beg is not aligned by 8
+  __sanitizer_annotate_contiguous_container(&t[1], &t[0] + 100, &t[1] + 10,
+                                            &t[0] + 50);
+}
+
 int main(int argc, char **argv) {
   assert(argc == 2);
   if (!strcmp(argv[1], "crash"))
     return TestCrash();
   else if (!strcmp(argv[1], "bad-bounds"))
     BadBounds();
+  else if (!strcmp(argv[1], "bad-alignment"))
+    BadAlignment();
 }
-// CHECK-CRASH: AddressSanitizer: container-overflow
-// CHECK-BAD: ERROR: AddressSanitizer: bad parameters to __sanitizer_annotate_contiguous_container
@@ -1,6 +1,7 @@
 // RUN: %clangxx_asan -O %s -o %t
 // RUN: not %run %t crash 2>&1 | FileCheck --check-prefix=CHECK-CRASH %s
-// RUN: not %run %t bad-bounds 2>&1 | FileCheck --check-prefix=CHECK-BAD %s
+// RUN: not %run %t bad-bounds 2>&1 | FileCheck --check-prefix=CHECK-BAD-BOUNDS %s
+// RUN: not %run %t bad-alignment 2>&1 | FileCheck --check-prefix=CHECK-BAD-ALIGNMENT %s
 // RUN: env ASAN_OPTIONS=detect_container_overflow=0 %run %t crash
 //





More information about the llvm-commits mailing list